@@ -40,14 +40,19 @@ __all__ = [
 ]
 
 
-def verify_token(source, token, **kwargs):
+def verify_access(source, token, **kwargs):
     """Vérifie avec le serveur LDAP si le token d'authentification
-    est toujours valide.
+    est toujours valide, puis vérifie si l'URL demandée est autorisée.
 
     La fonction vérifie d'abord dans le registre d'APIs
     si le token utilisé n'a pas déjà été vérifié par un service de confiance.
     Si ce n'est pas le cas, alors une vérification est effectuée auprès de
-    l'annuaire LDAP et le résultat est stocké dans le registre d'APIs."""
+    l'annuaire LDAP et le résultat est stocké dans le registre d'APIs.
+
+    Puis elle vérifie dans la configuration URL_ACL si l'utilisateur
+    associé à ce token a le droit d'accéder à l'URL de la requête.
+    Par défaut, si l'utilisateur n'existe pas dans l'ACL il a accès à tout.
+    """
 
     key = 'token:{}'.format(token)
     env = kwargs.get('env', None)
@@ -83,12 +88,20 @@ def verify_token(source, token, **kwargs):
                 API_REGISTRY.expire(key, 3600)
                 # on force l'enregistrement dans redis à expirer
                 # au bout d'une heure
-                return username
 
         else:
             # le token a déjà été vérifié une fois
             username = result.decode('utf-8')
+        filtered_urls = CONFIG['URL_ACL'].get(username)
+        if not filtered_urls:
             return username
+        else:
+            filtered_urls = filtered_urls.replace(' ', '').split(',')
+            for filtered_url in filtered_urls:
+                if path.startswith(filtered_url):
+                    return username
+            else:
+                return False
     else:
         return True
 
@@ -204,7 +217,7 @@ class Api(object):
             # dans le couple (username, password)
             username = False
         else:
-            username = verify_token(
+            username = verify_access(
                 headers['X-Real-Ip'],
                 token,
                 service=self.service,
